@@ -1,13 +1,13 @@
 package Sah::Schema::perl::distname;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.023'; # VERSION
+our $DATE = '2019-11-28'; # DATE
+our $VERSION = '0.024'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl distribution name',
     match => '\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\z',
     'x.perl.coerce_rules' => [
-        'str_normalize_perl_distname',
+        'From_str::normalize_perl_distname',
     ],
 
     # provide a default completion which is from list of installed perl distributions
@@ -30,7 +30,7 @@ Sah::Schema::perl::distname - Perl distribution name
 
 =head1 VERSION
 
-This document describes version 0.023 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2019-07-26.
+This document describes version 0.024 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2019-11-28.
 
 =head1 HOMEPAGE
 
