@@ -1,7 +1,7 @@
 package Sah::Schema::perl::filename;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.023'; # VERSION
+our $DATE = '2019-11-28'; # DATE
+our $VERSION = '0.024'; # VERSION
 
 our $schema = [str => {
     summary => 'Filename (Perl script/module/POD)',
@@ -34,7 +34,7 @@ This schema comes with convenience completion too.
 
 _
     'x.perl.coerce_rules' => [
-        'str_convert_perl_pm_or_pod_to_path',
+        'From_str::convert_perl_pm_or_pod_to_path',
     ],
     'x.completion' => sub {
         require Complete::File;
@@ -70,7 +70,7 @@ Sah::Schema::perl::filename - Filename (Perl script/module/POD)
 
 =head1 VERSION
 
-This document describes version 0.023 of Sah::Schema::perl::filename (from Perl distribution Sah-Schemas-Perl), released on 2019-07-26.
+This document describes version 0.024 of Sah::Schema::perl::filename (from Perl distribution Sah-Schemas-Perl), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
