@@ -1,7 +1,7 @@
 package Sah::Schema::perl::modname;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.023'; # VERSION
+our $DATE = '2019-11-28'; # DATE
+our $VERSION = '0.024'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module name',
@@ -18,7 +18,7 @@ _
     match => '\A[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*\z',
 
     'x.perl.coerce_rules' => [
-        'str_normalize_perl_modname',
+        'From_str::normalize_perl_modname',
     ],
 
     # provide a default completion which is from list of installed perl modules
@@ -41,7 +41,7 @@ Sah::Schema::perl::modname - Perl module name
 
 =head1 VERSION
 
-This document describes version 0.023 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2019-07-26.
+This document describes version 0.024 of Sah::Schema::perl::modname (from Perl distribution Sah-Schemas-Perl), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
