@@ -1,7 +1,7 @@
 package Sah::Schema::perl::pm_filename;
 
-our $DATE = '2019-07-26'; # DATE
-our $VERSION = '0.023'; # VERSION
+our $DATE = '2019-11-28'; # DATE
+our $VERSION = '0.024'; # VERSION
 
 our $schema = [str => {
     summary => 'Filename (.pm file)',
@@ -31,7 +31,7 @@ This schema comes with convenience completion too.
 
 _
     'x.perl.coerce_rules' => [
-        'str_convert_perl_pm_to_path',
+        'From_str::convert_perl_pm_to_path',
     ],
     'x.completion' => sub {
         require Complete::File;
@@ -68,7 +68,7 @@ Sah::Schema::perl::pm_filename - Filename (.pm file)
 
 =head1 VERSION
 
-This document describes version 0.023 of Sah::Schema::perl::pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2019-07-26.
+This document describes version 0.024 of Sah::Schema::perl::pm_filename (from Perl distribution Sah-Schemas-Perl), released on 2019-11-28.
 
 =head1 DESCRIPTION
 
